# YiD Emailer

My experiments with emailing services.


## Brevo:
I decided to use 3rd party emailing service Brevo to have a convenient dashboard for reviewing all emails sent.
Brevo has a generous free tier.
To set it up, go to https://app.brevo.com/settings/keys/api, generate an API key and create `BREVO_API_KEY` GitHub secret with it.
